@@ -33,7 +33,7 @@ import remote
 import local
 
 
-VERSION = '0.2.2'
+VERSION = '0.2.3'
 
 
 def hook_setup(cmd):
@@ -41,7 +41,7 @@ def hook_setup(cmd):
     sys.exit(0)
 
 def hook_destroy(cmd):
-    local.confirm('Please confirm that you want to destroy your service')
+    local.confirm('Please confirm destruction')
 
 def hook___version(cmd):
     print 'DotCloud CLI version {0}'.format(VERSION)
@@ -81,10 +81,14 @@ def run_remote(cmd):
             'confirm': local.confirm,
             'call': lambda x: run_command(x, True),
             'echo': lambda x: sys.stdout.write('{0}\n'.format(x)),
-            'echo_error': lambda x: sys.stderr.write('{0}\n'.format(x))
+            'echo_error': lambda x: sys.stderr.write('{0}\n'.format(x)),
+            'set_verbose': r.set_verbose
             }
     for args in cmd:
         c = args[0]
+        if c not in handlers:
+            # Ignore unsupported commands
+            return
         if len(args) > 1:
             args = tuple(args[1:])
             ret = handlers[c](*args)
@@ -136,8 +140,8 @@ def run_command(cmd, internal=False):
             print data['data']
     except socket.error, e:
         utils.die('Cannot reach DotCloud service ("{0}").\nPlease check the connectivity and try again.'.format(str(e)))
-#    except Exception, e:
-#        utils.die('DotCloud service unavailable ("{0}").\nPlease try again later. If the problem persists, send an email to support@dotcloud.com.'.format(e))
+    except Exception, e:
+        utils.die('DotCloud service unavailable ("{0}").\nPlease try again later. If the problem persists, send an email to support@dotcloud.com.'.format(e))
     finally:
         try:
             req.close()
