@@ -20,14 +20,17 @@
 
 from setuptools import setup
 
+VERSION = '0.2.3'
+
+# rm -rf build dist *.egg-info && python ./setup.py clean sdist upload -r pypi
 
 setup(
         name                = 'dotcloud',
-        version             = '0.1.3',
+        version             = VERSION,
         author              = 'DotCloud inc.',
         author_email        = 'support@dotcloud.com',
         url                 = 'http://www.dotcloud.com',
         description         = 'DotCloud meta-package',
-        install_requires    = ['dotcloud.cli >= 0.1.3'],
+        install_requires    = ['dotcloud.cli >= {0}'.format(VERSION)],
         zip_safe            = False
 )
